You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@dubbo.apache.org by al...@apache.org on 2021/09/21 16:05:51 UTC

[dubbo] branch master updated: fix #8855 remove @Service in java doc and comment (#8856)

This is an automated email from the ASF dual-hosted git repository.

albumenj pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/dubbo.git


The following commit(s) were added to refs/heads/master by this push:
     new f175e98  fix #8855 remove @Service in java doc and comment (#8856)
f175e98 is described below

commit f175e9843a3872ebc6567bfa1ca610a76b920b0c
Author: changfu <ch...@gmail.com>
AuthorDate: Wed Sep 22 00:05:40 2021 +0800

    fix #8855 remove @Service in java doc and comment (#8856)
    
    * fix #8855 remove @Service in java doc and comment
    
    * recovery wrong fix
---
 .../factory/annotation/ServiceClassPostProcessor.java    | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/dubbo-config/dubbo-config-spring/src/main/java/org/apache/dubbo/config/spring/beans/factory/annotation/ServiceClassPostProcessor.java b/dubbo-config/dubbo-config-spring/src/main/java/org/apache/dubbo/config/spring/beans/factory/annotation/ServiceClassPostProcessor.java
index 5fc1582..2cd1ec9 100644
--- a/dubbo-config/dubbo-config-spring/src/main/java/org/apache/dubbo/config/spring/beans/factory/annotation/ServiceClassPostProcessor.java
+++ b/dubbo-config/dubbo-config-spring/src/main/java/org/apache/dubbo/config/spring/beans/factory/annotation/ServiceClassPostProcessor.java
@@ -77,7 +77,7 @@ import static org.springframework.core.annotation.AnnotationUtils.getAnnotationA
 import static org.springframework.util.ClassUtils.resolveClassName;
 
 /**
  * {@link BeanFactoryPostProcessor} used for processing of {@link Service @Service} annotated classes. it's also the
  * infrastructure class of XML {@link BeanDefinitionParser} on &lt;dubbo:annotation /&gt;
  *
  * @see AnnotationBeanDefinitionParser
@@ -138,7 +138,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
     }
 
     /**
-     * Registers Beans whose classes was annotated {@link Service}
+     * Registers Beans whose classes was annotated {@link DubboService}
      *
      * @param packagesToScan The base packages to scan
      * @param registry       {@link BeanDefinitionRegistry}
@@ -173,7 +173,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
                 }
 
                 if (logger.isInfoEnabled()) {
-                    logger.info(beanDefinitionHolders.size() + " annotated Dubbo's @Service Components { " +
+                    logger.info(beanDefinitionHolders.size() + " annotated Dubbo's @DubboService Components { " +
                             beanDefinitionHolders +
                             " } were scanned under package[" + packageToScan + "]");
                 }
@@ -181,7 +181,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
             } else {
 
                 if (logger.isWarnEnabled()) {
-                    logger.warn("No Spring Bean annotating Dubbo's @Service was found under package["
+                    logger.warn("No Spring Bean annotating Dubbo's @DubboService was found under package["
                             + packageToScan + "]");
                 }
 
@@ -233,7 +233,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
 
     /**
      * Finds a {@link Set} of {@link BeanDefinitionHolder BeanDefinitionHolders} whose bean type annotated
-     * {@link Service} Annotation.
+     * {@link DubboService} Annotation.
      *
      * @param scanner       {@link ClassPathBeanDefinitionScanner}
      * @param packageToScan package to scan
@@ -262,7 +262,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
     }
 
     /**
-     * Registers {@link ServiceBean} from new annotated {@link Service} {@link BeanDefinition}
+     * Registers {@link ServiceBean} from new annotated {@link DubboService} {@link BeanDefinition}
      *
      * @param beanDefinitionHolder
      * @param registry
@@ -278,7 +278,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
         Annotation service = findServiceAnnotation(beanClass);
 
         /**
          * The {@link AnnotationAttributes} of @Service annotation
          */
         AnnotationAttributes serviceAnnotationAttributes = getAnnotationAttributes(service, false, false);
 
@@ -335,7 +335,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
      * Generates the bean name of {@link ServiceBean}
      *
      * @param serviceAnnotationAttributes
-     * @param interfaceClass              the class of interface annotated {@link Service}
+     * @param interfaceClass              the class of interface annotated {@link DubboService}
      * @return ServiceBean@interfaceClassName#annotatedServiceBeanName
      * @since 2.7.3
      */
@@ -77,7 +77,7 @@ import static org.springframework.core.annotation.AnnotationUtils.getAnnotationA
 
 /**
- * {@link BeanFactoryPostProcessor} used for processing of {@link Service @Service} annotated classes. it's also the
+ * {@link BeanFactoryPostProcessor} used for processing of {@link DubboService @Service} annotated classes. it's also the
  * infrastructure class of XML {@link BeanDefinitionParser} on &lt;dubbo:annotation /&gt;
  *
@@ -278,7 +278,7 @@ public class ServiceClassPostProcessor implements BeanDefinitionRegistryPostProc
 
         /**
-         * The {@link AnnotationAttributes} of @Service annotation
+         * The {@link AnnotationAttributes} of @DubboService annotation
          */
         AnnotationAttributes serviceAnnotationAttributes = getAnnotationAttributes(service, false, false);